#
# spec file for package python-referencing
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-referencing%{psuffix}
Version:        0.36.1
Release:        1.1
Summary:        JSON Referencing + Python
License:        MIT
URL:            https://github.com/python-jsonschema/referencing
# only use tarball created by tar_scm service,
# as PyPi does not include the suite git submodule
# and github tarballs do not include the .git directory
# required by hatch_vcs and setuptools_scm
#
# using obs_scm does **not** work...
Source:         referencing-%{version}.tar.gz
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
# runtime dependencies
BuildRequires:  %{python_module attrs >= 24.3.0}
BuildRequires:  %{python_module rpds-py >= 0.22.3}
BuildRequires:  %{python_module typing_extensions >= 4.4.0 if %python-base < 3.13}
%if %{with test}
# SECTION test requirements
BuildRequires:  %{python_module pytest >= 8.3.3}
BuildRequires:  %{python_module jsonschema-specifications}
BuildRequires:  %{python_module jsonschema}
BuildRequires:  %{python_module packaging >= 24.2}
BuildRequires:  %{python_module pytest-subtests >= 0.14.1}
# /SECTION
%endif
BuildRequires:  fdupes
Requires:       python-attrs >= 22.2.0
Requires:       python-rpds-py >= 0.7.0
Requires:       python-typing_extensions >= 4.4.0
BuildArch:      noarch
%python_subpackages

%description
JSON Referencing + Python

%prep
%setup -q -n referencing-%{version}

%build
%pyproject_wheel

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if %{without test}
%files %{python_files}
%doc CHANGELOG.rst README.rst
%license COPYING
%{python_sitelib}/referencing/
%{python_sitelib}/referencing-%{version}.dist-info/
%endif

%changelog
* Fri Jan 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.36.1:
  * Add a lower pin on typing-extensions for the version we depend
    on.
* Fri Jan 17 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.36.0:
  * Declare support for Python 3.13.
* Thu May  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.1:
  * Make Resource.pointer also properly handle empty pointers
    (which refer to the root document).
    This fix likely only affects you if you were using that
    function directly, as Resource.lookup already handles empty
    fragments.
* Wed Apr 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.0:
  * Make Registry.contents raise NoSuchResource when needed.
  * Update pre-commit hooks.
  * Run coverage with 3.12
  * Try convincing RTD to use uv.
  * uv and minor workflow tweaks
  * Use uv for envs, particularly the requirements env.
  * [pre-commit.ci] pre-commit autoupdate
  * Whatever pyright regression was present is still present.
  * [pre-commit.ci] pre-commit autoupdate
  * Bump suite from `71c85d0` to `87851a6`
  * Bump suite from `d3fdf35` to `71c85d0`
  * Bump suite from `e3fe0aa` to `d3fdf35`
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.34.0:
  * Also look inside definitions keywords even on newer dialects.
    The specification recommends doing so regardless of the rename
    to $defs.
  * Ensure non-blocking mypy compatibility by @jamescw19 in #130
* Mon Jan 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.33.0:
  * Add a referencing.jsonschema.SchemaResource type alias to go
    along with the other JSON Schema specialized types.
* Sun Jan  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.32.1:
  * We CannotDetermineSpecification for $schema kyes that aren't
    strs
  * [pre-commit.ci] pre-commit autoupdate
  * Update requirements.
  * Enable more ruff rulesets.
  * Remove an unneeded doc ext, we have no CLI.
  * [pre-commit.ci] pre-commit autoupdate
  * Bump actions/setup-python from 4 to 5
  * Update pre-commit hooks.
* Thu Dec  7 2023 kastl@b1-systems.de
- Update to version 0.32.0:
  * Add Specification.detect.
* Thu Nov 30 2023 kastl@b1-systems.de
- Update to version 0.31.1:
  * Do more silly things to pepper over type checking nonsense.
  * Minor noxfile tweaking.
  * Add the explicit Tidelift link.
  * Complain about spurious type: ignores.
  * [pre-commit.ci] pre-commit autoupdate
* Thu Nov 16 2023 kastl@b1-systems.de
- Update to version 0.31.0:
  * Add referencing.jsonschema.EMPTY_REGISTRY.
  * [pre-commit.ci] pre-commit autoupdate
  * Update requirements.
  * Enable TCH rules for slightly reducing runtime imports.
  * [pre-commit.ci] pre-commit autoupdate
  * Add tests for Registry being truthy or falsy.
  * Apparently this setting is now autodetected.
  * yarl -> url.py in the (trivial) docs usage.
  * Ignore the dirhtml directory usable for docs generation.
  * Unpin pyright, as whatever was previously broken seems fixed.
  * [pre-commit.ci] pre-commit autoupdate
  * Update requirements.
  * Pull in some style ignores that we don't really need yet.
  * [pre-commit.ci] pre-commit autoupdate
  * Update requirements.
  * referencing, not Bowtie
  * New pip-compile default.
  * Update requirements.
  * Remove the now-unneeded noqa's.
  * Ask ruff to fix things when it runs.
  * [pre-commit.ci] pre-commit autoupdate
  * [pre-commit.ci] pre-commit autoupdate
  * Update requirements.
  * [pre-commit.ci] pre-commit autoupdate
  * [pre-commit.ci] pre-commit autoupdate
  * Add and ensure the noxfile gets documented.
  * Bump actions/checkout from 3 to 4
  * [pre-commit.ci] pre-commit autoupdate
  * Few more ruff rules.
  * Bump docs requirements.
  * [pre-commit.ci] pre-commit autoupdate
  * Bump suite from `fa1b818` to `9153b05`
  * [pre-commit.ci] pre-commit autoupdate
  * Bump suite from `b094fe5` to `fa1b818`
  * Minor tweaks to some annotations.
  * [pre-commit.ci] pre-commit autoupdate
* Sun Aug  6 2023 kastl@b1-systems.de
- Update to version 0.30.2:
  * Document why a number of private objects are documented.
  * Build docs with 3.11 in ReadTheDocs
* Sun Aug  6 2023 kastl@b1-systems.de
- Update to version 0.30.1:
  * Ensure submodules are checked out when building a release.
  * Enable another ruff ruleset.
  * One fewer thing in the README (which is likely less confusing).
  * Bump suite from `6e126a9` to `b094fe5`
  * [pre-commit.ci] pre-commit autoupdate
  * Add a few additional interlinks to the JSON Schema
    specification.
  * Make the noxfile support passing a less temporary directory for
    building docs.
  * Update requirements.
  * More correct listing of nox envs for the GitHub actions
    workflow
  * [pre-commit.ci] pre-commit autoupdate
* Tue Jul 18 2023 kastl@b1-systems.de
- Update to version 0.30.0:
  * Declare support for 3.12.
  * Update the referencing suite.
* Tue Jul 18 2023 kastl@b1-systems.de
- Update to version 0.29.3:
  * Spelling.
* Tue Jul 18 2023 kastl@b1-systems.de
- Update to version 0.29.2:
  * Improve the hashability of exceptions when they contain
    hashable data.
  * [pre-commit.ci] pre-commit autoupdate
  * Bump suite from `9335e4a` to `fe891e8`
* Thu Jul  6 2023 kastl@b1-systems.de
- Update to version 0.29.1:
  * Update pre-commit hooks.
  * Minor rewording of the caching section and give it a
    subsection.
  * Bump suite from `cb57930` to `9335e4a`
  * [pre-commit.ci] pre-commit autoupdate
  * Bump suite from `445c8ee` to `cb57930`
  * Bump suite from `f6fa54d` to `445c8ee`
  * Don't use nox.session.create_tmp.
* Thu Jun  1 2023 kastl@b1-systems.de
- Update to version 0.29.0:
  * Implement referencing.retrieval.to_cached_resource
  * Ensure more things raise non-subclassable exceptions.
* Thu Jun  1 2023 kastl@b1-systems.de
- Update to version 0.28.6:
  * Move to using Trusted Publishers.
  * Ensure twine checks the README in strict mode.
  * [pre-commit.ci] pre-commit autoupdate
  * Enable markdown coverage in CI.
  * Try again with the extra coverage job in CI.
* Thu May 25 2023 kastl@b1-systems.de
- Update to version 0.28.5:
  * Fill in the missing coverage, and ensure it runs in CI.
  * Add pip-audit to CI.
  * Explicitly ensure we catch calling .anchor on a nonexistent
    resource.
* Wed May 24 2023 kastl@b1-systems.de
- Update to version 0.28.4:
  * More explicit field aliasing for silly type checker behavior.
  * Update requirements.
  * Supposedly dependabot supports pip-compile, let's see.
  * Catch accidental hardcoded links in docs.
  * [pre-commit.ci] pre-commit autoupdate
* Tue May 23 2023 kastl@b1-systems.de
- Update to version 0.28.3:
  * Update ruff's config for the removal of keep-runtime-typing.
* Thu May 18 2023 kastl@b1-systems.de
- Update to version 0.28.2:
  * Pin the pyright version until I understand what's changed.
  * Re-add the packaging classifiers.
  * [pre-commit.ci] pre-commit autoupdate
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Thu May  4 2023 kastl@b1-systems.de
- Update to version 0.28.1:
  * Move the type: ignore for converter with pyright.
  * Explicitly note you probably don't mean to touch Resolver.
  * Bump suite from `89016c7` to `f6fa54d`
  * [pre-commit.ci] pre-commit autoupdate
  * v0.28.0 -> CHANGELOG
* Tue May  2 2023 kastl@b1-systems.de
- Update to version 0.28.0:
  * Add a simple-ish example to the doc homepage.
  * Looks like Hatchling needs a bump before this can actually
    happen.
  * Add the new JSON and JSON Schema classifiers, hooray!
* Wed Apr 26 2023 kastl@b1-systems.de
- Update to version 0.27.4:
  * Minor simplification to the docs structure.
  * Bump suite from `e744bfc` to `89016c7`
  * Bump the referencing suite.
  * [pre-commit.ci] pre-commit autoupdate
* Tue Apr 25 2023 kastl@b1-systems.de
- Update to version 0.27.3:
  * Fix whatever typing change causes pyright to think frozen
    classes aren't frozen.
  * Also strip empty fragments when using __getiem__ on Registries.
  * Bump wntrblm/nox from 2022.11.21 to 2023.04.22
* Fri Apr 14 2023 kastl@b1-systems.de
- Update to version 0.27.2:
  * Yet another stab at anchor lookup from non-canonical URIs.
  * Bump suite from `2751845` to `e8927d9`
  * [pre-commit.ci] pre-commit autoupdate
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.27.1:
  * Add a note to the changelog.
  * Enable the type annotation linter.
  * Slight improvements to a few more docstrings.
  * Update requirements.
  * Bump suite from `5f47bda` to `e8927d9`
  * [pre-commit.ci] pre-commit autoupdate
* Tue Apr  4 2023 kastl@b1-systems.de
- Update to version 0.27.0:
  * Fix looking up anchors from non-canonical URIs.
  * [pre-commit.ci] pre-commit autoupdate
* Tue Mar 28 2023 Matej Cepl <mcepl@suse.com>
- Split package into multibuild to avoid a build cycle.
* Tue Mar 28 2023 kastl@b1-systems.de
- Update to version 0.26.4:
  * One more example of non-public API
  * Add a note on spec-incorrect behavior.
* Tue Mar 28 2023 kastl@b1-systems.de
- Update to version 0.26.3:
  * First pass at an explicit list of (non-)public API
* Tue Mar 28 2023 kastl@b1-systems.de
- Update to version 0.26.2:
  * Also suggest a correct pointer for #/.
  * Fix the double wording in the InvalidAnchor exception message.
* Mon Mar 27 2023 kastl@b1-systems.de
- Update to version 0.26.1:
  * Update the changelog.
* Mon Mar 27 2023 kastl@b1-systems.de
- Update to version 0.26.0:
  * Try to be more helpful when someone forgets a slash in JSON
    pointers.
  * Exclude bots from release notes.
  * [pre-commit.ci] pre-commit autoupdate
* Fri Mar 24 2023 Johannes Kastl <kastl@b1-systems.de>
- new package python-referencing required by
  python-jsonschema-specifications
